/* bmp.h: Header file for miscellaneous functions
 *
 * Ankit Mohan, 3/2/2003 - Got out of my OLD game code
 * Ankit Mohan, 10/07/2003 - Removed text/font related functions.
 */


/* Loads a BMP file and returns it, with height and width.
 * Allocation for the file is done in this function. Memory should be 
 * freed by the caller. 
 * The image data is returned in a 1-dimensional array that contains the pixel
 * RGBA values one from the top down to the bottom row (each row from left to
 * right). The alpha value is set to 255. 
 *
 * returns -1 if file not found
 *         -2 if compressed BMP (cannot load)
 *         -3 if not 24 bit BMP (cannot load)
 *
 * Sample code:
 *
 * int w, h;
 * unsigned char *img;
 * load_BMP("filename.bmp", &img, &h, &w);
 *
 */
int load_BMP(char *name, unsigned char **image, int *height, int *width);

// returns tne next power of 2 > len
int setDim(int len);

// this pads the texture loaded to powers of 2
int load_padded_BMP(char *name, unsigned char **image, int *height, int *width);


/* Save a BMP file.
 *  
 * The image data is expected in a 1-dimensional array that contains the pixel
 * RGBA values one from the bottom up to the top row (each row from left to
 * right). The alpha value is ignored. 
 *
 * returns -1 cannot write to file
 *          0 on success
 */
int save_BMP(char *name, unsigned char *image, int width, int height);
